=======
*pydmt*
=======

.. image:: https://img.shields.io/pypi/v/pydmt

.. image:: https://img.shields.io/github/license/veltzer/pydmt

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

project website: https://veltzer.github.io/pydmt

author: Mark Veltzer

version: 0.1.43


